@@ -90,6 +90,7 @@ namespace tgui
         m_titleButtons                     {other.m_titleButtons},
         m_titleTextSize                    {other.m_titleTextSize},
         m_currentChildWindowMouseCursor    {other.m_currentChildWindowMouseCursor},
+        m_closeBehavior                    {other.m_closeBehavior},
         m_closeButton                      {other.m_closeButton},
         m_minimizeButton                   {other.m_minimizeButton},
         m_maximizeButton                   {other.m_maximizeButton},
@@ -131,6 +132,7 @@ namespace tgui
         m_titleButtons                     {std::move(other.m_titleButtons)},
         m_titleTextSize                    {std::move(other.m_titleTextSize)},
         m_currentChildWindowMouseCursor    {std::move(other.m_currentChildWindowMouseCursor)},
+        m_closeBehavior                    {std::move(other.m_closeBehavior)},
         m_closeButton                      {std::move(other.m_closeButton)},
         m_minimizeButton                   {std::move(other.m_minimizeButton)},
         m_maximizeButton                   {std::move(other.m_maximizeButton)},
@@ -177,6 +179,7 @@ namespace tgui
             m_titleButtons                      = other.m_titleButtons;
             m_titleTextSize                     = other.m_titleTextSize;
             m_currentChildWindowMouseCursor     = other.m_currentChildWindowMouseCursor;
+            m_closeBehavior                     = other.m_closeBehavior;
             m_closeButton                       = other.m_closeButton;
             m_minimizeButton                    = other.m_minimizeButton;
             m_maximizeButton                    = other.m_maximizeButton;
@@ -224,6 +227,7 @@ namespace tgui
             m_titleButtons                      = std::move(other.m_titleButtons);
             m_titleTextSize                     = std::move(other.m_titleTextSize);
             m_currentChildWindowMouseCursor     = std::move(other.m_currentChildWindowMouseCursor);
+            m_closeBehavior                     = std::move(other.m_closeBehavior);
             m_closeButton                       = std::move(other.m_closeButton);
             m_minimizeButton                    = std::move(other.m_minimizeButton);
             m_maximizeButton                    = std::move(other.m_maximizeButton);
@@ -562,6 +566,20 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    void ChildWindow::setCloseBehavior(CloseBehavior behavior)
+    {
+        m_closeBehavior = behavior;
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    ChildWindow::CloseBehavior ChildWindow::getCloseBehavior() const
+    {
+        return m_closeBehavior;
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void ChildWindow::close()
     {
         bool abort = false;
@@ -570,7 +588,14 @@ namespace tgui
             return;
 
         onClose.emit(this);
-        destroy();
+
+        if (m_closeBehavior == CloseBehavior::Remove)
+        {
+            if (m_parent)
+                m_parent->remove(shared_from_this());
+        }
+        else if (m_closeBehavior == CloseBehavior::Hide)
+            setVisible(false);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1259,6 +1284,13 @@ namespace tgui
 
         node->propertyValuePairs[U"TitleButtons"] = std::make_unique<DataIO::ValueNode>(serializedTitleButtons);
 
+        if (m_closeBehavior == CloseBehavior::None)
+            node->propertyValuePairs[U"CloseBehavior"] = std::make_unique<DataIO::ValueNode>("None");
+        else if (m_closeBehavior == CloseBehavior::Hide)
+            node->propertyValuePairs[U"CloseBehavior"] = std::make_unique<DataIO::ValueNode>("Hide");
+        else if (m_closeBehavior == CloseBehavior::Remove)
+            node->propertyValuePairs[U"CloseBehavior"] = std::make_unique<DataIO::ValueNode>("Remove");
+
         return node;
     }
 
@@ -1317,6 +1349,18 @@ namespace tgui
 
         if (node->propertyValuePairs[U"MaximumSize"])
             setMaximumSize(Vector2f{node->propertyValuePairs[U"MaximumSize"]->value});
+
+        if (node->propertyValuePairs[U"CloseBehavior"])
+        {
+            if (node->propertyValuePairs[U"CloseBehavior"]->value == U"None")
+                setCloseBehavior(CloseBehavior::None);
+            else if (node->propertyValuePairs[U"CloseBehavior"]->value == U"Hide")
+                setCloseBehavior(CloseBehavior::Hide);
+            else if (node->propertyValuePairs[U"CloseBehavior"]->value == U"Remove")
+                setCloseBehavior(CloseBehavior::Remove);
+            else
+                throw Exception{U"Failed to parse CloseBehavior property. Only the values None, Hide and Remove are correct."};
+        }
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
