@@ -231,6 +231,14 @@ TEST_CASE("[ScrollablePanel]")
         REQUIRE(widget1->getSize() == tgui::Vector2f{200, 100});
     }
 
+    SECTION("Scrollbar access")
+    {
+        panel->setSize({400, 300});
+        panel->setContentSize({600, 500});
+        testScrollbarAccess(panel->getVerticalScrollbar());
+        testScrollbarAccess(panel->getHorizontalScrollbar());
+    }
+
     SECTION("Events / Signals")
     {
         unsigned int mousePressedCount = 0;
@@ -456,4 +464,36 @@ TEST_CASE("[ScrollablePanel]")
             TEST_DRAW("ScrollablePanel_SmallContentSize_HorizontalScrollbar.png")
         }
     }
+
+    SECTION("Dynamic resizing issues")
+    {
+        // The scrollable panel shouldn't enter an infinite loop when we resize its children
+        // when scrollbars appear so that the scrollbar isn't needed anymore.
+
+        panel->setSize(140, 115);
+        panel->getRenderer()->setBorders({1});
+
+        auto button = tgui::Button::create();
+        button->setSize("100%", "100%");
+        panel->add(button);
+        REQUIRE(button->getSize() == tgui::Vector2f{138, 113});
+        button->setPosition(1, 0);
+        REQUIRE(button->getSize() == tgui::Vector2f{138 - panel->getScrollbarWidth(), 113 - panel->getScrollbarWidth()});
+
+        button->setSize(20, 10);
+        button->setPosition(0, 1);
+        button->setSize("100%", "100%");
+        REQUIRE(button->getSize() == tgui::Vector2f{138 - panel->getScrollbarWidth(), 113 - panel->getScrollbarWidth()});
+
+        panel->removeAllWidgets();
+
+        for (unsigned i = 1; i <= 2; ++i)
+        {
+            const int btnPerRow = 2;
+            auto btn = tgui::Button::create();
+            btn->setSize(("100%"-(btnPerRow+1)*tgui::Layout("5%"))/btnPerRow, tgui::bindWidth(btn));
+            btn->setPosition("5%"+(i%btnPerRow)*(tgui::bindWidth(btn)+"5%"), "5%"+(i/btnPerRow)*(tgui::bindWidth(btn)+"5%"));
+            panel->add(btn);
+        }
+    }
 }
